#
# Configuration file for using the xslt library
#
XSLT_LIBDIR="-L/var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_0ez1k168mj/croot/libxslt_1679578053883/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib"
XSLT_LIBS="-lxslt -L/var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_0ez1k168mj/croot/libxslt_1679578053883/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib -lxml2 "
XSLT_PRIVATE_LIBS=""
XSLT_INCLUDEDIR="-I/var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_0ez1k168mj/croot/libxslt_1679578053883/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/include"
MODULE_VERSION="xslt-1.1.37"
